<?php

namespace WKO\Controllers;

use WKO\Model\Options;

/**
 * Name: Woocommerce
 * Intance Woocommerce classes
 * @package Controllers
 * @since 1.0.0
 */
class Webhooks 
{
	private $gateway;
	private $class;

	/**
	 * Class constructor
	 * @since 1.0.0
	 * @param string $gateways
     * @param string $class
	 */
	public function __construct( $gateway, $class )
	{
		$this->gateway = $gateway;
		$this->class   = $class;

		$webhook = $this->get_instance( $class );
		
		if ( $webhook ) {
			add_action( 'woocommerce_api_'. $this->get_endpoint(), [ $webhook, 'handle_notifications' ] );
		}
	}

	/**
	 * Get webhook endpoint
	 * @since 1.0.0
	 * @return string
	 */
	private function get_endpoint()
	{
		$opt   = new Options;
		$token = $opt->get( "_webhook_token_$this->gateway" );
		
		if ( ! $token ) {
			$bytes = random_bytes(15);
			$token = bin2hex( $bytes );
			
			$opt->update( "_webhook_token_$this->gateway", $token );
		}
		
		return $token .= "-$this->gateway";
	}

	/**
	 * Get class instance
	 * @since 1.0.0
	 * @return object|bool
	 */
	public function get_instance()
	{
		$classname = $this->class;

		if ( $pos = strrpos( $this->class, '\\' ) ) {
			$classname = substr($this->class, $pos + 1);
		}

		$instance = WKO_PLUGIN_NAMESPACE . "\\Controllers\\Webhooks\\{$classname}";

		if ( class_exists( $instance ) ) {
			return new $instance;
		}

		return false;
	}
	
}