<?php

namespace WKO\Helpers;

use WKO\Controllers\Notifications;
use WKO\Controllers\Woocommerce;

/**
 * Name: Functions
 * Handle hooks/filters functions
 * @package Helpers
 * @since 1.0.0
 */
class Functions
{
    /**
     * Load admin scripts and styles
     * @since 1.0.0
     * @return void
     */
    public static function enqueue_admin_scripts() 
    {
        wp_enqueue_script( 'admin', Config::__dist( 'admin.js' ) );
        wp_enqueue_style( 'admin', Config::__dist( 'admin.css' ) );

        ## libs
        wp_enqueue_style( 'fontawesome', 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css' );
    }

    /**
     * Load theme scripts and styles
     * @since 1.0.0
     * @return void
     */
    public static function enqueue_theme_scripts() 
    {
        if ( ! is_admin() ) {
            wp_enqueue_script( 'theme', Config::__dist( 'theme.js' ) );
            wp_enqueue_style( 'theme', Config::__dist( 'theme.css' ) );
        }
    }

    /**
     * Load plugin text domain
     * @since 1.0.0
     * @return void
     */
    public static function initialize()
    {		
        $locale = apply_filters( 'plugin_locale', get_locale(), WKO_PLUGIN_SLUG );

		load_textdomain( WKO_PLUGIN_SLUG, Config::__dir() . "/languages/" . WKO_PLUGIN_SLUG . "-$locale.mo" );
		load_plugin_textdomain( WKO_PLUGIN_SLUG, false, Config::__dir() . '/languages/' );
    }

    /**
     * Init Woocommerce classes
     * @since 1.0.0
     * @return Woocommerce
     */
    public static function woo_init()
    {
        if ( class_exists( 'WooCommerce' ) ) {
            return new Woocommerce;
        }

        new Notifications(  
            WKO_PLUGIN_NAME, 
            sprintf( ': %s',
                __( 'The plugin depends on WooCommerce to work!', 'wc-koin-official')
            ),
            'error' 
        );
    }

    /**
     * Create extra link on plugins page
     * @since 1.0.0
     * @param array $arr
     * @param string $name
     * @return array
     */
    public static function settings_link( $arr, $name ){

        if( $name === Config::__base() && class_exists( 'WooCommerce' ) ) {

            $label = sprintf( '<a href="admin.php?page=wc-settings&tab=checkout&section=wc-koin-billet" id="deactivate-koin-official-payments" aria-label="%s">%s</a>',
                __( 'Settings for Koin Official Payments', 'wc-koin-official' ),
                __( 'Settings for ticket slip', 'wc-koin-official' )
            );

            $arr['settings'] = $label;
        }

        return $arr;
    }

    /**
     * handle plugins actions
     * @since 1.0.0
     * @return void
     */
    public static function handle_actions()
    {
        $action_name = WKO_PLUGIN_PREFIX . '_action';
        $vars = [];

        if ( is_array( $_REQUEST ) && isset( $_REQUEST[ $action_name ] ) ) {
            $vars = array_map( 'sanitize_text_field', $_REQUEST[ $action_name ] );
        }
        if ( is_array( $vars ) && isset( $vars[ $action_name ] ) ) {
            $controller = Utils::parse_controller( $vars[ $action_name ] );

            new $controller( $vars );
        }
    }
}