<?php

namespace WKO\Services\Koin;

use DateInterval;
use DateTime;

/**
 * Name: Authentication
 * Generate the athentication token
 * @package Services\Koin
 * @since 1.0.0
 */
class Authentication 
{
    public $_header;
    public $_payload;

    public function __construct()
    {
        $this->get_header();
        $this->get_payload();
    }
    /**
     * Get koin auth header
     * @since 1.0.0
     * @return void
     */
    public function get_header()
    {
        $secret = Config::consumer_key();
        $this->_header = json_encode( [
            'kid' => $secret,
            'typ' => 'JWT',
            'alg' => 'HS512'
        ] );
    }

    /**
     * Get koin auth payload
     * @since 1.0.0
     * @return void
     */
    public function get_payload()
    {
        $date = $this->get_time();
        $iss = Config::store_iss();

        $this->_payload =  json_encode( [
            'aud' => 'api-koin',
            'iss' => $iss,
            'iat' => $date['iat'],
            'exp' => $date['exp']
        ] );
    }

    /**
     * Generate timestamps
     * @since 1.0.0
     * @return void 
     */
    public function get_time()
    {
        $time = new DateTime();
        $iat = $time->getTimestamp();


        $time->add( new DateInterval( 'PT10M' ) );
        $exp = $time->getTimestamp();

        return [
            'iat' => $iat,
            'exp' => $exp,
        ];
    }

    /**
     * Generate the authentication hash
     * @since 1.0.0
     * @return string
     */
    public function gen_auth()
    {
        $secret = Config::secret_key();
        $unsignedToken = str_replace( "=", "", base64_encode( $this->_header ) ) . '.' .  str_replace( "=", "", base64_encode( $this->_payload ) );
        $signature     = $this->base64url_encode( hash_hmac( 'SHA512', $unsignedToken, $secret, true ) );
        $token         = $unsignedToken . '.' . $signature;

        return "Bearer $token";
    }

    public function base64url_encode($data) {
        return rtrim( strtr( base64_encode( $data ), '+/', '-_', ), '=' );
    }
}
